use std::collections::HashMap;
use std::error::Error;

use ldap3::{LdapConn, Scope, SearchEntry};

// create an LDAP connection object
pub fn connect(ldap_connection_info: HashMap<&str, &str>) -> LdapConn {
  let conn_string = format!("{}://{}:{}",
    ldap_connection_info.get("protocol").unwrap(),
    ldap_connection_info.get("server").unwrap(),
    ldap_connection_info.get("port").unwrap());
  let ldap_conn = LdapConn::new(&conn_string);

  if ldap_conn.is_ok() {
    return ldap_conn.ok().unwrap();
  } else {
    panic!("{:?}", ldap_conn.err().unwrap());
  }
}

// perform an LDAP search
pub fn do_search(ldap_conn: LdapConn, search_base: &str) -> Result<(), Box<Error>> {
  let (rs, _res) = ldap_conn.search(
    search_base,
    Scope::Subtree,
    "(&(objectClass=*))",
    vec!["*"]
  )?.success()?;

  for entry in rs {
    let search_entry = SearchEntry::construct(entry);
    if search_entry.attrs.get("uid").is_some() {
      println!("{:?}", search_entry.attrs.get("uid").unwrap()[0]);
    }
  }

  Ok(())
}
